Message schemas — bodhi 4.0.0 documentation

# Message schemas

`cornice_sphinx` does not yet have the ability to render documentation for the `/message-schemas/` API, so we will include docblock documentation for that service here instead.

class `bodhi.server.services.schemas.` `MessageSchemasV1`(request: pyramid.util.Request, context: None = None)

  Defines resources for serving Bodhi’s message schemas.

  Operations acting on the collection are served at `/message-schemas/v1/` and operations acting on a single schema are served at `/message-schemas/v1/<topic>`.

  `collection_get`() → Iterable[str]

    List schemas.

    This method responds to the `/message-schemas/v1/` endpoint.

    Returns: | A list of message topics that Bodhi supports.

  `get`() → dict

    Retrieve and render a single message schema.

    This API responses to the `/message_schemas/v1/<topic>` endpoint.

    Returns: | The requested message schema.